/*
 * $Id: SVGGraphics.java,v 1.1 2000/04/26 14:52:59 ivan Exp $
 */
/*--------------------------------------------------------------------------------
 Copyright Stichting Mathematisch Centrum 2000

  Permission to use and distribute this software and its
  documentation for any purpose is hereby granted without fee, provided that
  the above copyright notice, author statement and this permission,
  warranties and liability notice appear in all copies of this software
  and related documentation.

  Warranties
  Stichting Mathematisch Centrum makes no warranties, express or implied, with
  regard to this software. In particular, but without limitation, SMC makes
  no warranty of fitness for a particular use, no warranty of freedom from
  infringement of any patent or copyright, nor any warranty as to accuracy.
  Accordingly, SMC assumes no obligation to furnish assistance of any kind
  whatsoever or to furnish additional information or documentation.

  Liability
  In no event shall Stichting Mathematisch Centrum be liable for any damages
  arising out of or in connection with the use or performance of this
  software.
*/

package cwi.SVGGraphics;

import java.awt.*;
import java.awt.image.*;
import java.awt.font.*;
import java.util.*;
import java.net.URL;

/**
* A simple image filter, which adds a "url" property to the image object.
* Otherwise the image is not changed.
* <p>
* A possible and simple use of the filter is as follows:
* <pre>
*     import java.awt.image.*;
*     ...
*     ImageFilter addProperty = new SVGImageFilter("The.URL.of.the.image");
*     FilteredImageSource imageSource = new FilteredImageSource(oldImg.getSource(),addProperty); 
*     Image newImg = Toolkit.getDefaultToolkit().createImage(imageSource);
* </pre>
* The class also includes two static methods which simply include these lines, and can be
* used as a simple tool.
*
* @author Ivan Herman
* @version 1.0
*/
public class SVGImageFilter extends ImageFilter
{
  private String url = "";

  /**
  * @param s the url to be stored with the image.
  */
  public SVGImageFilter(String s)
  {
    url = s;
  }

  /**
  * @param s the url to be stored with the image. The stored property is the string
  * <code>s.toExternalForm()</code>. 
  */
  public SVGImageFilter(URL s)
  {
    url = s.toExternalForm();
  }
  
  /**
  * This is the inherited method from <code>ImageFilter</code> which sets the new property.
  */
  public void setProperties(Hashtable props)
  {
    props.put("url",url);
    super.setProperties(props);
  }
  
  /**
  * Create a new image with a property with a key <code>"url"</code>.
  * @param s the property to be stored.
  */
  public static Image addURL(Image img,String s)
  {
    ImageFilter dummy = new SVGImageFilter(s);
    return Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(img.getSource(),dummy));
  }

  /**
  * Create a new image with a property with a key <code>"url"</code>.
  * @param s the property to be stored. The stored property is the string
  * <code>s.toExternalForm()</code>.
  */
  public static Image addURL(Image img,URL s)
  {
    ImageFilter dummy = new SVGImageFilter(s);
    return Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(img.getSource(),dummy));
  }
}
 
  
    